# -*- coding: utf-8 -*-
"""dictd C5 format writer"""

import io
import sys

import gadict


FINAME = None
FONAME = None
if len(sys.argv) >= 2:
    FINAME = sys.argv[1]
if len(sys.argv) >= 3:
    FONAME = sys.argv[2]

FIN = io.open(FINAME, mode='r', buffering=1, encoding="utf-8")

PARSER = gadict.Parser()
try:
    DOM = PARSER.parse(FIN)
except gadict.ParseException as ex:
    sys.stdout.write("{:s}{:s}\n".format(FINAME, repr(ex)))
    if __debug__:
        import traceback
        traceback.print_exc()
    exit(1)
finally:
    FIN.close()


PRELUDE = DOM[0]

with open(FONAME+".name", "w") as f:        # for dictfmt -s
    if PRELUDE.name is not None:
        f.write(PRELUDE.name)
    f.write("\n")

with open(FONAME+".url", "w") as f:         # for dictfmt -u
    if len(PRELUDE.urls) > 0:
        f.write(PRELUDE.urls[0])
    f.write("\n")


if FONAME is None:
    FOUT = sys.stdout
else:
    FOUT = open(FONAME, "w")

if PRELUDE.name is not None:
    FOUT.write("Dictionary name: ")
    FOUT.write(PRELUDE.name)
    FOUT.write("\n\n")
FOUT.write("Project URLs: ")
FOUT.write(" , ".join(PRELUDE.urls))
FOUT.write("\n\n")
FOUT.write("Project licenses: ")
FOUT.write(", ".join(PRELUDE.licences))
FOUT.write("\n\n")
FOUT.write(PRELUDE.about)
FOUT.write("\n")

for idx in range(1, len(DOM)):
    article = DOM[idx]
    FOUT.write("_____\n\n")
    title = "; ".join(article[0].keys())
    FOUT.write(title)
    FOUT.write("\n\n")
    for (word, (pron, attrs)) in article[0].items():
        if word == "approach":
            FOUT.write(str(article[0]))
        FOUT.write("  ")
        FOUT.write(word)
        FOUT.write("\n")
        if pron is not None:
            FOUT.write("    [")
            FOUT.write(pron)
            FOUT.write("]\n")
        if len(attrs) > 0:
            FOUT.write("    ")
            l = list(attrs)
            l.sort()
            FOUT.write(", ".join(l))
            FOUT.write("\n")
    FOUT.write("\n")
    for (pos, trs, exs) in article[1]:
        FOUT.write("  ")
        if pos is not None:
            FOUT.write("⟨")
            FOUT.write(pos)
            FOUT.write("⟩ ")
        for (lang, tr) in trs:
            if lang == "ru":
                FOUT.write(tr)
                break
        FOUT.write("\n")
